==> LibreOffice_7.3.6.2_Linux_x86-64_deb_sdk.tar.gz: opt/libreoffice7.3/sdk/docs/idl/ref/search/functions_74.js <==
var searchData=
[
  ['tabpageactivated',['tabPageActivated',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tab_1_1XTabPageContainerListener.html#a8c2a8f4c5881fe01e2f344c3faef00be',1,'com::sun::star::awt::tab::XTabPageContainerListener']]],
  ['terminate',['terminate',['../interfacecom_1_1sun_1_1star_1_1io_1_1XActiveDataControl.html#a74a45d2648335936561898c390281a6a',1,'com::sun::star::io::XActiveDataControl::terminate()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XPrinter.html#a74a45d2648335936561898c390281a6a',1,'com::sun::star::awt::XPrinter::terminate()'],['../interfacecom_1_1sun_1_1star_1_1frame_1_1XDesktop.html#a82241f4ab1e6505280b31a0f86d2e9e7',1,'com::sun::star::frame::XDesktop::terminate()']]],
  ['terminated',['terminated',['../interfacecom_1_1sun_1_1star_1_1io_1_1XStreamListener.html#a883ec8661849559723cd1ea0fe9e26bf',1,'com::sun::star::io::XStreamListener']]],
  ['textchanged',['textChanged',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTextListener.html#a025d4bbb1b9c1b3776fbdc7da1d697af',1,'com::sun::star::awt::XTextListener']]],
  ['tilewindows',['tileWindows',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XTask.html#ac24b59c5455eccc3de106c901e8ff497',1,'com::sun::star::frame::XTask']]],
  ['titlechanged',['titleChanged',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XTitleChangeListener.html#a4ac183de31e0f5b2dbbd86e18ce20ea0',1,'com::sun::star::frame::XTitleChangeListener']]],
  ['toback',['toBack',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTopWindow.html#a6053c984b166df7d3db5ee4c4ad65b99',1,'com::sun::star::awt::XTopWindow']]],
  ['tofront',['toFront',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTopWindow.html#a48a9c646659814220ac869bbcb60b52c',1,'com::sun::star::awt::XTopWindow']]],
  ['togglefloatingmode',['toggleFloatingMode',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XDockableWindowListener.html#a2cd60152c5fde7841cafa8e61ede513a',1,'com::sun::star::awt::XDockableWindowListener']]],
  ['tolower',['toLower',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XCharacterClassification.html#ada571ffbebd1d104a2406ec6e2faa88c',1,'com::sun::star::i18n::XCharacterClassification']]],
  ['totitle',['toTitle',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XCharacterClassification.html#a91c8ca6fca8074459727d0e044127bfb',1,'com::sun::star::i18n::XCharacterClassification']]],
  ['totop',['toTop',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1XPresenterHelper.html#a077a54338d43cfeaada3b6f35a76b635',1,'com::sun::star::drawing::XPresenterHelper']]],
  ['toupper',['toUpper',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XCharacterClassification.html#a9a22b03ec3937771151592f68f17ca7d',1,'com::sun::star::i18n::XCharacterClassification']]],
  ['transferablesflavorschanged',['transferablesFlavorsChanged',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDragSourceContext.html#ae444123d2c6af52cc4ea89944735c553',1,'com::sun::star::datatransfer::dnd::XDragSourceContext']]],
  ['transform',['transform',['../interfacecom_1_1sun_1_1star_1_1chart2_1_1XTransformation.html#ad34c96e9785fb16267a01f0cf09b6f15',1,'com::sun::star::chart2::XTransformation::transform()'],['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XSprite.html#a04c39d9fd8dfe1bd3ab4c7c05aea3079',1,'com::sun::star::rendering::XSprite::transform()']]],
  ['translateaccelerators',['translateAccelerators',['../interfacecom_1_1sun_1_1star_1_1embed_1_1XInplaceClient.html#a5b766f4fa004a1e0620621e958d2b547',1,'com::sun::star::embed::XInplaceClient::translateAccelerators()'],['../interfacecom_1_1sun_1_1star_1_1embed_1_1XInplaceObject.html#a5b766f4fa004a1e0620621e958d2b547',1,'com::sun::star::embed::XInplaceObject::translateAccelerators()']]],
  ['translatetoexternal',['translateToExternal',['../interfacecom_1_1sun_1_1star_1_1uri_1_1XExternalUriReferenceTranslator.html#aa2661e263cb2113bae68a735deecb843',1,'com::sun::star::uri::XExternalUriReferenceTranslator']]],
  ['translatetointernal',['translateToInternal',['../interfacecom_1_1sun_1_1star_1_1uri_1_1XExternalUriReferenceTranslator.html#aa4e9118d6eca0d0cc89ef32d77ad847d',1,'com::sun::star::uri::XExternalUriReferenceTranslator']]],
  ['transliterate',['transliterate',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XTransliteration.html#a31f394c76ab8a3a7bb608b1e081ac3ca',1,'com::sun::star::i18n::XTransliteration']]],
  ['transliteratechar2char',['transliterateChar2Char',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XExtendedTransliteration.html#a6702b74edc3c1dace7ec165c6f3fba4f',1,'com::sun::star::i18n::XExtendedTransliteration']]],
  ['transliteratechar2string',['transliterateChar2String',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XExtendedTransliteration.html#acdefd647330eed4350a990f6a658788b',1,'com::sun::star::i18n::XExtendedTransliteration']]],
  ['transliteraterange',['transliterateRange',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XTransliteration.html#a83775210859ca9ca244296ce5d31881c',1,'com::sun::star::i18n::XTransliteration']]],
  ['transliteratestring2string',['transliterateString2String',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XExtendedTransliteration.html#a03ef983113149f3aa974d3f469d164c8',1,'com::sun::star::i18n::XExtendedTransliteration']]],
  ['transmit',['transmit',['../interfacecom_1_1sun_1_1star_1_1ucb_1_1XContentTransmitter.html#ab51a74ff97791d6e4c4af16b32c0ff1b',1,'com::sun::star::ucb::XContentTransmitter']]],
  ['trashcontent',['trashContent',['../interfacecom_1_1sun_1_1star_1_1ucb_1_1XRecycler.html#aa29d8d3eed99dda4df8683ae6143a1f7',1,'com::sun::star::ucb::XRecycler']]],
  ['travelnext',['travelNext',['../interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XWizard.html#af82452ef20d8f72691431b4464f9207f',1,'com::sun::star::ui::dialogs::XWizard']]],
  ['travelprevious',['travelPrevious',['../interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XWizard.html#a7d61e5e4e2d792798688a487b916cac7',1,'com::sun::star::ui::dialogs::XWizard']]],
  ['treecollapsed',['treeCollapsed',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeExpansionListener.html#a7298fd66c14264865d42433825971cac',1,'com::sun::star::awt::tree::XTreeExpansionListener']]],
  ['treecollapsing',['treeCollapsing',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeExpansionListener.html#a236e288e552bc929a2e5c6cbdcae9da2',1,'com::sun::star::awt::tree::XTreeExpansionListener']]],
  ['treeexpanded',['treeExpanded',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeExpansionListener.html#a13e27be83d023e0f587a6ce617b2518c',1,'com::sun::star::awt::tree::XTreeExpansionListener']]],
  ['treeexpanding',['treeExpanding',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeExpansionListener.html#a34c37164940bc4bcfc938dba5d1c45f3',1,'com::sun::star::awt::tree::XTreeExpansionListener']]],
  ['treenodeschanged',['treeNodesChanged',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeDataModelListener.html#af7b29438778b94a9729c1073503bc78f',1,'com::sun::star::awt::tree::XTreeDataModelListener']]],
  ['treenodesinserted',['treeNodesInserted',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeDataModelListener.html#a185c533430a14b1757879875d4f9d925',1,'com::sun::star::awt::tree::XTreeDataModelListener']]],
  ['treenodesremoved',['treeNodesRemoved',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeDataModelListener.html#af35eeae74fb3f72e0b2889ba75cb7958',1,'com::sun::star::awt::tree::XTreeDataModelListener']]],
  ['treestructurechanged',['treeStructureChanged',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeDataModelListener.html#aeae81f7703cd798bc6a1e0adbc93806d',1,'com::sun::star::awt::tree::XTreeDataModelListener']]],
  ['trigger',['trigger',['../interfacecom_1_1sun_1_1star_1_1task_1_1XJobExecutor.html#a41be13aecc0916ae7b3105e4ec2291f5',1,'com::sun::star::task::XJobExecutor']]],
  ['truncate',['truncate',['../interfacecom_1_1sun_1_1star_1_1io_1_1XTruncate.html#a6cdeae8dd0ba505874283c6d41a91418',1,'com::sun::star::io::XTruncate']]]
];

==> LibreOffice_7.4.0.3_Linux_x86-64_deb_sdk.tar.gz: opt/libreoffice7.4/sdk/docs/idl/ref/search/functions_74.js <==
var searchData=
[
  ['tabpageactivated',['tabPageActivated',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tab_1_1XTabPageContainerListener.html#a8c2a8f4c5881fe01e2f344c3faef00be',1,'com::sun::star::awt::tab::XTabPageContainerListener']]],
  ['terminate',['terminate',['../interfacecom_1_1sun_1_1star_1_1io_1_1XActiveDataControl.html#a74a45d2648335936561898c390281a6a',1,'com::sun::star::io::XActiveDataControl::terminate()'],['../interfacecom_1_1sun_1_1star_1_1awt_1_1XPrinter.html#a74a45d2648335936561898c390281a6a',1,'com::sun::star::awt::XPrinter::terminate()'],['../interfacecom_1_1sun_1_1star_1_1frame_1_1XDesktop.html#a82241f4ab1e6505280b31a0f86d2e9e7',1,'com::sun::star::frame::XDesktop::terminate()']]],
  ['terminated',['terminated',['../interfacecom_1_1sun_1_1star_1_1io_1_1XStreamListener.html#a883ec8661849559723cd1ea0fe9e26bf',1,'com::sun::star::io::XStreamListener']]],
  ['textchanged',['textChanged',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTextListener.html#a025d4bbb1b9c1b3776fbdc7da1d697af',1,'com::sun::star::awt::XTextListener']]],
  ['tilewindows',['tileWindows',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XTask.html#ac24b59c5455eccc3de106c901e8ff497',1,'com::sun::star::frame::XTask']]],
  ['titlechanged',['titleChanged',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XTitleChangeListener.html#a4ac183de31e0f5b2dbbd86e18ce20ea0',1,'com::sun::star::frame::XTitleChangeListener']]],
  ['toback',['toBack',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTopWindow.html#a6053c984b166df7d3db5ee4c4ad65b99',1,'com::sun::star::awt::XTopWindow']]],
  ['tofront',['toFront',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XTopWindow.html#a48a9c646659814220ac869bbcb60b52c',1,'com::sun::star::awt::XTopWindow']]],
  ['togglefloatingmode',['toggleFloatingMode',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XDockableWindowListener.html#a2cd60152c5fde7841cafa8e61ede513a',1,'com::sun::star::awt::XDockableWindowListener']]],
  ['tolower',['toLower',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XCharacterClassification.html#ada571ffbebd1d104a2406ec6e2faa88c',1,'com::sun::star::i18n::XCharacterClassification']]],
  ['totitle',['toTitle',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XCharacterClassification.html#a91c8ca6fca8074459727d0e044127bfb',1,'com::sun::star::i18n::XCharacterClassification']]],
  ['totop',['toTop',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1XPresenterHelper.html#a077a54338d43cfeaada3b6f35a76b635',1,'com::sun::star::drawing::XPresenterHelper']]],
  ['toupper',['toUpper',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XCharacterClassification.html#a9a22b03ec3937771151592f68f17ca7d',1,'com::sun::star::i18n::XCharacterClassification']]],
  ['transferablesflavorschanged',['transferablesFlavorsChanged',['../interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDragSourceContext.html#ae444123d2c6af52cc4ea89944735c553',1,'com::sun::star::datatransfer::dnd::XDragSourceContext']]],
  ['transform',['transform',['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XSprite.html#a04c39d9fd8dfe1bd3ab4c7c05aea3079',1,'com::sun::star::rendering::XSprite']]],
  ['translateaccelerators',['translateAccelerators',['../interfacecom_1_1sun_1_1star_1_1embed_1_1XInplaceClient.html#a5b766f4fa004a1e0620621e958d2b547',1,'com::sun::star::embed::XInplaceClient::translateAccelerators()'],['../interfacecom_1_1sun_1_1star_1_1embed_1_1XInplaceObject.html#a5b766f4fa004a1e0620621e958d2b547',1,'com::sun::star::embed::XInplaceObject::translateAccelerators()']]],
  ['translatetoexternal',['translateToExternal',['../interfacecom_1_1sun_1_1star_1_1uri_1_1XExternalUriReferenceTranslator.html#aa2661e263cb2113bae68a735deecb843',1,'com::sun::star::uri::XExternalUriReferenceTranslator']]],
  ['translatetointernal',['translateToInternal',['../interfacecom_1_1sun_1_1star_1_1uri_1_1XExternalUriReferenceTranslator.html#aa4e9118d6eca0d0cc89ef32d77ad847d',1,'com::sun::star::uri::XExternalUriReferenceTranslator']]],
  ['transliterate',['transliterate',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XTransliteration.html#a31f394c76ab8a3a7bb608b1e081ac3ca',1,'com::sun::star::i18n::XTransliteration']]],
  ['transliteratechar2char',['transliterateChar2Char',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XExtendedTransliteration.html#a6702b74edc3c1dace7ec165c6f3fba4f',1,'com::sun::star::i18n::XExtendedTransliteration']]],
  ['transliteratechar2string',['transliterateChar2String',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XExtendedTransliteration.html#acdefd647330eed4350a990f6a658788b',1,'com::sun::star::i18n::XExtendedTransliteration']]],
  ['transliteraterange',['transliterateRange',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XTransliteration.html#a83775210859ca9ca244296ce5d31881c',1,'com::sun::star::i18n::XTransliteration']]],
  ['transliteratestring2string',['transliterateString2String',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XExtendedTransliteration.html#a03ef983113149f3aa974d3f469d164c8',1,'com::sun::star::i18n::XExtendedTransliteration']]],
  ['transmit',['transmit',['../interfacecom_1_1sun_1_1star_1_1ucb_1_1XContentTransmitter.html#ab51a74ff97791d6e4c4af16b32c0ff1b',1,'com::sun::star::ucb::XContentTransmitter']]],
  ['trashcontent',['trashContent',['../interfacecom_1_1sun_1_1star_1_1ucb_1_1XRecycler.html#aa29d8d3eed99dda4df8683ae6143a1f7',1,'com::sun::star::ucb::XRecycler']]],
  ['travelnext',['travelNext',['../interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XWizard.html#af82452ef20d8f72691431b4464f9207f',1,'com::sun::star::ui::dialogs::XWizard']]],
  ['travelprevious',['travelPrevious',['../interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XWizard.html#a7d61e5e4e2d792798688a487b916cac7',1,'com::sun::star::ui::dialogs::XWizard']]],
  ['treecollapsed',['treeCollapsed',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeExpansionListener.html#a7298fd66c14264865d42433825971cac',1,'com::sun::star::awt::tree::XTreeExpansionListener']]],
  ['treecollapsing',['treeCollapsing',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeExpansionListener.html#a236e288e552bc929a2e5c6cbdcae9da2',1,'com::sun::star::awt::tree::XTreeExpansionListener']]],
  ['treeexpanded',['treeExpanded',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeExpansionListener.html#a13e27be83d023e0f587a6ce617b2518c',1,'com::sun::star::awt::tree::XTreeExpansionListener']]],
  ['treeexpanding',['treeExpanding',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeExpansionListener.html#a34c37164940bc4bcfc938dba5d1c45f3',1,'com::sun::star::awt::tree::XTreeExpansionListener']]],
  ['treenodeschanged',['treeNodesChanged',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeDataModelListener.html#af7b29438778b94a9729c1073503bc78f',1,'com::sun::star::awt::tree::XTreeDataModelListener']]],
  ['treenodesinserted',['treeNodesInserted',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeDataModelListener.html#a185c533430a14b1757879875d4f9d925',1,'com::sun::star::awt::tree::XTreeDataModelListener']]],
  ['treenodesremoved',['treeNodesRemoved',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeDataModelListener.html#af35eeae74fb3f72e0b2889ba75cb7958',1,'com::sun::star::awt::tree::XTreeDataModelListener']]],
  ['treestructurechanged',['treeStructureChanged',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeDataModelListener.html#aeae81f7703cd798bc6a1e0adbc93806d',1,'com::sun::star::awt::tree::XTreeDataModelListener']]],
  ['trigger',['trigger',['../interfacecom_1_1sun_1_1star_1_1task_1_1XJobExecutor.html#a41be13aecc0916ae7b3105e4ec2291f5',1,'com::sun::star::task::XJobExecutor']]],
  ['truncate',['truncate',['../interfacecom_1_1sun_1_1star_1_1io_1_1XTruncate.html#a6cdeae8dd0ba505874283c6d41a91418',1,'com::sun::star::io::XTruncate']]]
];
